pub struct PassportView {Show 13 fields
pub surname: Option<String>,
pub given_name: Option<String>,
pub date_of_birth: Option<String>,
pub sex: Option<String>,
pub birth_place: Option<String>,
pub nationality: Option<String>,
pub issuing_country: Option<String>,
pub passport_number: Option<String>,
pub passport_type: Option<String>,
pub national_identification_number: Option<String>,
pub issuing_authority: Option<String>,
pub issue_date: Option<String>,
pub expiration_date: Option<String>,
}Fields
surname: Option<String>given_name: Option<String>date_of_birth: Option<String>sex: Option<String>birth_place: Option<String>nationality: Option<String>issuing_country: Option<String>passport_number: Option<String>passport_type: Option<String>national_identification_number: Option<String>issue_date: Option<String>expiration_date: Option<String>Trait Implementations
Sourceimpl Clone for PassportView
impl Clone for PassportView
Sourcefn clone(&self) -> PassportView
fn clone(&self) -> PassportView
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, Passport> for PassportView
impl CompositeEncryptable<KeySlotIds, SymmetricKeySlotId, Passport> for PassportView
Sourceimpl<UT> ConvertError<UT> for PassportView
impl<UT> ConvertError<UT> for PassportView
fn try_convert_unexpected_callback_error( e: UnexpectedUniFFICallbackError, ) -> Result<Self>
Sourceimpl Debug for PassportView
impl Debug for PassportView
Sourceimpl Decryptable<KeySlotIds, SymmetricKeySlotId, PassportView> for Passport
impl Decryptable<KeySlotIds, SymmetricKeySlotId, PassportView> for Passport
fn decrypt( &self, ctx: &mut KeyStoreContext<'_, KeySlotIds>, key: SymmetricKeySlotId, ) -> Result<PassportView, CryptoError>
Sourceimpl Default for PassportView
impl Default for PassportView
Sourcefn default() -> PassportView
fn default() -> PassportView
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for PassportView
impl<'de> Deserialize<'de> for PassportView
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl<UT> FfiConverter<UT> for PassportView
impl<UT> FfiConverter<UT> for PassportView
Sourceconst TYPE_ID_META: MetadataBuffer
const TYPE_ID_META: MetadataBuffer
Type ID metadata, serialized into a [MetadataBuffer].
Sourcetype FfiType = RustBuffer
type FfiType = RustBuffer
The low-level type used for passing values of this type over the FFI. Read more
Sourcefn lower(v: Self) -> RustBuffer
fn lower(v: Self) -> RustBuffer
Lower a rust value of the target type, into an FFI value of type Self::FfiType. Read more
Sourcefn try_lift(buf: RustBuffer) -> Result<Self>
fn try_lift(buf: RustBuffer) -> Result<Self>
Lift a rust value of the target type, from an FFI value of type Self::FfiType. Read more
Sourceimpl From<&PassportDataV1> for PassportView
impl From<&PassportDataV1> for PassportView
Sourcefn from(src: &PassportDataV1) -> Self
fn from(src: &PassportDataV1) -> Self
Converts to this type from the input type.
Sourceimpl From<&PassportView> for PassportDataV1
impl From<&PassportView> for PassportDataV1
Sourcefn from(src: &PassportView) -> Self
fn from(src: &PassportView) -> Self
Converts to this type from the input type.
Sourceimpl From<PassportView> for JsValuewhere
PassportView: Serialize,
impl From<PassportView> for JsValuewhere
PassportView: Serialize,
Sourcefn from(value: PassportView) -> Self
fn from(value: PassportView) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
impl FromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &PassportViewwhere
PassportView: Serialize,
impl IntoWasmAbi for &PassportViewwhere
PassportView: Serialize,
Sourceimpl IntoWasmAbi for PassportViewwhere
PassportView: Serialize,
impl IntoWasmAbi for PassportViewwhere
PassportView: Serialize,
Sourceimpl<UT> Lift<UT> for PassportView
impl<UT> Lift<UT> for PassportView
Sourceimpl<UT> LiftRef<UT> for PassportView
impl<UT> LiftRef<UT> for PassportView
type LiftType = PassportView
Sourceimpl<UT> LiftReturn<UT> for PassportView
impl<UT> LiftReturn<UT> for PassportView
Sourcetype ReturnType = <PassportView as Lift<UT>>::FfiType
type ReturnType = <PassportView as Lift<UT>>::FfiType
FFI return type for trait interfaces
Sourcefn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
fn try_lift_successful_return(v: Self::ReturnType) -> Result<Self>
Lift a successfully returned value from a trait interface
fn lift_foreign_return(
ffi_return: Self::ReturnType,
call_status: RustCallStatus,
) -> Self
fn lift_foreign_return( ffi_return: Self::ReturnType, call_status: RustCallStatus, ) -> Self
Lift a foreign returned value from a trait interface Read more
fn lift_error(_buf: RustBuffer) -> Self
fn lift_error(_buf: RustBuffer) -> Self
Lift a Rust value for a callback interface method error result Read more
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
fn handle_callback_unexpected_error(e: UnexpectedUniFFICallbackError) -> Self
Lift a Rust value for an unexpected callback interface error Read more
Sourceimpl<UT> Lower<UT> for PassportView
impl<UT> Lower<UT> for PassportView
Sourceimpl<UT> LowerError<UT> for PassportView
impl<UT> LowerError<UT> for PassportView
Sourcefn lower_error(obj: Self) -> RustBuffer
fn lower_error(obj: Self) -> RustBuffer
Lower this value for scaffolding function return Read more
Sourceimpl<UT> LowerReturn<UT> for PassportView
impl<UT> LowerReturn<UT> for PassportView
Sourcetype ReturnType = <PassportView as Lower<UT>>::FfiType
type ReturnType = <PassportView as Lower<UT>>::FfiType
The type that should be returned by scaffolding functions for this type. Read more
Sourcefn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
fn lower_return(v: Self) -> Result<Self::ReturnType, RustCallError>
Lower the return value from an scaffolding call Read more
fn handle_failed_lift(
error: LiftArgsError,
) -> Result<Self::ReturnType, RustCallError>
fn handle_failed_lift( error: LiftArgsError, ) -> Result<Self::ReturnType, RustCallError>
Lower the return value for failed argument lifts Read more
Sourceimpl OptionFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for PassportViewwhere
PassportView: Serialize,
impl OptionIntoWasmAbi for PassportViewwhere
PassportView: Serialize,
Sourceimpl PartialEq for PassportView
impl PartialEq for PassportView
Sourceimpl RefFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<PassportView>
type Anchor = SelfOwner<PassportView>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for PassportView
impl Serialize for PassportView
Sourceimpl Tsify for PassportView
impl Tsify for PassportView
const DECL: &'static str = "export interface PassportView {\n surname: string | undefined;\n givenName: string | undefined;\n dateOfBirth: string | undefined;\n sex: string | undefined;\n birthPlace: string | undefined;\n nationality: string | undefined;\n issuingCountry: string | undefined;\n passportNumber: string | undefined;\n passportType: string | undefined;\n nationalIdentificationNumber: string | undefined;\n issuingAuthority: string | undefined;\n issueDate: string | undefined;\n expirationDate: string | undefined;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl<UT> TypeId<UT> for PassportView
impl<UT> TypeId<UT> for PassportView
const TYPE_ID_META: MetadataBuffer
Sourceimpl VectorFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for PassportViewwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for PassportViewwhere
PassportView: Serialize,
impl VectorIntoWasmAbi for PassportViewwhere
PassportView: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for PassportView
impl WasmDescribe for PassportView
Sourceimpl WasmDescribeVector for PassportView
impl WasmDescribeVector for PassportView
impl StructuralPartialEq for PassportView